# STABILIZER + TIMELIME

Code repository for library stabilizer-timelime - https://pypi.org/project/stabilizer-timelime/

### Description

Pending

### How to build the package?

To build the package we use poetry as build-backend. Install poetry using pip - <br>
`pip install poetry` or `pip3 install poetry`

In root directory (directory that contains `pyproject.toml`) run the build command - <br>
`python3 -m build` <br>
This command will generate a wheel (a pre-built binary package) in `dist/` directory <br>


### How to install this package?

To install the latest version run - <br>
`pip install stabilizer-timelime` or `pip3 install stabilizer-timelime`


To install custom built wheel - <br>
`pip install <path-to-wheel-file>` or `pip3 install <path-to-wheel-file>`